(wrap-error-handler handler err-handler)A middleware that catches an exception thrown by cling.response/fail! and invoke specified error handler
A middleware that catches an exception thrown by cling.response/fail! and invoke specified error handler
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |