cling.util.ansi


*enable-ansi?*clj

source

blackclj

(black text__5076__auto__)
source

black-bgclj

(black-bg text__5076__auto__)
source

blueclj

(blue text__5076__auto__)
source

blue-bgclj

(blue-bg text__5076__auto__)
source

bold-blackclj

(bold-black text__5076__auto__)
source

bold-black-bgclj

(bold-black-bg text__5076__auto__)
source

bold-blueclj

(bold-blue text__5076__auto__)
source

bold-blue-bgclj

(bold-blue-bg text__5076__auto__)
source

bold-cyanclj

(bold-cyan text__5076__auto__)
source

bold-cyan-bgclj

(bold-cyan-bg text__5076__auto__)
source

bold-greenclj

(bold-green text__5076__auto__)
source

bold-green-bgclj

(bold-green-bg text__5076__auto__)
source

bold-magentaclj

(bold-magenta text__5076__auto__)
source

bold-magenta-bgclj

(bold-magenta-bg text__5076__auto__)
source

bold-redclj

(bold-red text__5076__auto__)
source

bold-red-bgclj

(bold-red-bg text__5076__auto__)
source

bold-whiteclj

(bold-white text__5076__auto__)
source

bold-white-bgclj

(bold-white-bg text__5076__auto__)
source

bold-yellowclj

(bold-yellow text__5076__auto__)
source

bold-yellow-bgclj

(bold-yellow-bg text__5076__auto__)
source

color-boxclj

(color-box text ansi-fn)
source

cyanclj

(cyan text__5076__auto__)
source

cyan-bgclj

(cyan-bg text__5076__auto__)
source

greenclj

(green text__5076__auto__)
source

green-bgclj

(green-bg text__5076__auto__)
source

magentaclj

(magenta text__5076__auto__)
source

magenta-bgclj

(magenta-bg text__5076__auto__)
source

redclj

(red text__5076__auto__)
source

red-bgclj

(red-bg text__5076__auto__)
source

red-boxclj

(red-box text)
source

strip-ansiclj

(strip-ansi string)

Removes ANSI codes from a string, returning just the raw text.

Removes ANSI codes from a string, returning just the raw text.
sourceraw docstring

visual-lengthclj

(visual-length string)

Returns the length of the string, with ANSI codes stripped out.

Returns the length of the string, with ANSI codes stripped out.
sourceraw docstring

whiteclj

(white text__5076__auto__)
source

white-bgclj

(white-bg text__5076__auto__)
source

yellowclj

(yellow text__5076__auto__)
source

yellow-bgclj

(yellow-bg text__5076__auto__)
source

cljdoc builds & hosts documentation for Clojure/Script libraries