(strip-ansi string)Removes ANSI codes from a string, returning just the raw text.
Removes ANSI codes from a string, returning just the raw text.
(visual-length string)Returns the length of the string, with ANSI codes stripped out.
Returns the length of the string, with ANSI codes stripped out.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |